[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pycocoa: A basic, ctypes-based Python binding to the macOS Objective-C Cocoa runtime and several other macOS libraries.
  - pycocoa.__main__: Print pycocoa all public attributes, pycocoa version, Python release, etc.
  - pycocoa.apps: Types App and Tile, wrapping ObjC `NSApplication` and `NSDocktile`.
  - pycocoa.bases: (INTERNAL) Base classes for Python `Types`.
  - pycocoa.colors: Types Color, ColorError, CMYColor, GrayScaleColor, HSBColor, RGBColor, TintColor and UIColor wrapping Cocoa's `NSColor` and `enum`-like constants CMYColors, GrayScaleColors, HSBColors, RGBColors, TintColor, TintColors, UIColors and all Colors accessible by color space acronym like `CMY`, `GS`, `RGB`, etc.
  - pycocoa.deprecated: Deprecated classes, constants, functions, internals, etc.
  - pycocoa.dicts: Types FrozenDict and Dict, wrapping ObjC `NS[Mutable]Dictionary`.
  - pycocoa.faults: Handle uncaught `ObjC/NSExceptions` and other `fault`s similar to standard module `faulthandler` available since Python 3.3.
  - pycocoa.fonts: Type Font, etc., wrapping ObjC `NSFont`.
  - pycocoa.geometry: Types Point, Rect and Size, wrapping ObjC `NSPoint_t`, NSRect_t, `NSSize_t`.
  - pycocoa.getters: `get_...` functions to obtain ObjC classes, methods, protocols, etc.
  - pycocoa.internals: Mostly INTERNAL, private classes, functions, constants, etc.
  - pycocoa.lazily: Lazily import `pycocoa` modules and attributes, based on lazy_import from Brett Cannon's modutil.
  - pycocoa.lists: Type List, wrapping ObjC `NSMutableArray`.
  - pycocoa.menus: Types Item, ItemSeparator, Menu and MenuBar, wrapping ObjC `NSMenuItem` and `NSMenu` and Keys.
  - pycocoa.nstypes: ObjC classes `NS...` and conversions from `NS...` ObjC to Python instances.
  - pycocoa.octypes: ObjC `..._t` type definitions and some additional `ctypes`.
  - pycocoa.oslibs: Various ObjC and macOS libraries, signatures, constants, etc.
  - pycocoa.panels: Types OpenPanel and SavePanel, wrapping ObjC `NSOpenPanel` and `NSSavePanel`.
  - pycocoa.printers: Types Printer, Paper, PaperCustom and PaperMargins, wrapping ObjC `NSPrinter`, `PMPrinter`, `PMPaper` respectively `PMPaperMargins` plus several `get_...` print functions.
  - pycocoa.pytypes: Conversions from `NS...` ObjC instances to Python.
  - pycocoa.runtime: Classes `ObjCClass`, `ObjCInstance`, `ObjCMethod`, `ObjCSubclass`, etc.
  - pycocoa.screens: Types Frame and Screen, wrapping ObjC `NSScreen`.
  - pycocoa.sets: Types FrozenSet and Set, wrapping ObjC `NS[Mutable]Set`.
  - pycocoa.strs: Type Str, wrapping ObjC `NSStr[ing]`.
  - pycocoa.tables: Types Table and TableWindow, wrapping ObjC `NSTableView`, `NSWindow`.
  - pycocoa.tuples: Type Tuple, wrapping (immutable) ObjC `NSArray`.
  - pycocoa.utils: Private and public utility functions.
  - pycocoa.windows: Types AutoResize, Window, MediaWindow, Screen, WindowStyle, wrapping ObjC `NSWindow`, etc.